@@ -10,7 +10,7 @@
 #include <QDebug>
 #include <QMetaType>
 
-QString invalidIdCharacters = "[](){}\"'@*.,+-=/#$%&|:; \t\n<>";
+QString invalidIdCharacters = "[](){}\"'`@*.,+-=/#?%&|:;~ \t\n<>";
 QHash<NameWrapper,QPair<QChar,QChar>> wrapperChars;
 QHash<NameWrapper,QPair<QChar,bool>> wrapperEscapedEnding;
 QList<NameWrapper> sqlite3Wrappers;
@@ -912,3 +912,14 @@ QByteArray blobFromLiteral(const QString& value)
     QString hex = value.mid(2, value.length() - 3);
     return QByteArray::fromHex(hex.toLatin1());
 }
+
+QVariant idToBool(const QString &id)
+{
+    QString lower = id.toLower();
+    if (lower == "true")
+        return true;
+    else if (lower == "false")
+        return false;
+    else
+        return QVariant();
+}
